@@ -21,11 +21,11 @@ void bdmcmcCopulap_links( int *iter, int *burnin, int G[], double Ts[], double K
 			 double K_hat[], double p_links[],
 			 int *b, int *b_star, double D[], double Ds[], double *threshold )
 {
-	int iteration = *iter, burn_in = *burnin;
+	int iteration = *iter, burn_in = *burnin, b1 = *b;
 	
 	int index_selected_edge, selected_edge_i, selected_edge_j, selected_edge_ij, counter;
 
-	double Dsjj, Dsij, sum_diag, K022, a11, b1 = *b, sigmaj11, threshold_C = *threshold;
+	double Dsjj, Dsij, sum_diag, K022, a11, sigmaj11, threshold_C = *threshold;
 	int row, col, rowCol, i, j, k, ij, jj, nu_star, one = 1, two = 2, dim = *p, pxp = dim * dim, p1 = dim - 1, p1xp1 = p1 * p1, p2 = dim - 2, p2xp2 = p2 * p2, p2x2 = p2 * 2;
 
 	vector<double> sigma( pxp ); 
@@ -166,8 +166,8 @@ void bdmcmcCopulap_links( int *iter, int *burnin, int G[], double Ts[], double K
 				F77_NAME(dgemm)( &transN, &transT, &two, &two, &p2, &alpha, &K12xK22_inv[0], &two, &K12[0], &two, &beta, &K121[0], &two );		
 				// Finished (i,j) = 1------------------------------------------|
 
-				a11     = K[i * dim + i] - K121[0];	
-				sum_diag = - Dsij * K121[1] - Dsij * K121[2] + Dsjj * ( K022 - K121[3] );
+				a11      = K[i * dim + i] - K121[0];	
+				sum_diag = Dsjj * ( K022 - K121[3] ) - Dsij * ( K121[1] + K121[2] );
 
 				// nu_star = b + sum( Gf[,i] * Gf[,j] )
 				nu_star = b1;
@@ -238,7 +238,7 @@ void bdmcmcCopula( int *iter, int *burnin, int G[], double Ts[], double K[], int
 			 char *sample_graphs[], double graph_weights[], int *size_sample_g,
 			 int *b, int *b_star, double D[], double Ds[], double *threshold )
 {
-	int iteration = *iter, burn_in = *burnin;
+	int iteration = *iter, burn_in = *burnin, b1 = *b;
 	int counterallG = 0;
 	string string_g;
 	vector<string> sample_graphs_C( iteration - burn_in );
@@ -246,7 +246,7 @@ void bdmcmcCopula( int *iter, int *burnin, int G[], double Ts[], double K[], int
 	int index_selected_edge, selected_edge_i, selected_edge_j, selected_edge_ij, counter, size_sample_graph = *size_sample_g;
 	bool this_one;
 
-	double Dsjj, Dsij, sum_diag, K022, a11, b1 = *b, sigmaj11, threshold_C = *threshold;
+	double Dsjj, Dsij, sum_diag, K022, a11, sigmaj11, threshold_C = *threshold;
 	int row, col, rowCol, i, j, k, ij, jj, nu_star, one = 1, two = 2, dim = *p, pxp = dim * dim, p1 = dim - 1, p1xp1 = p1 * p1, p2 = dim - 2, p2xp2 = p2 * p2, p2x2 = p2 * 2;
 
 	vector<double> sigma( pxp ); 
@@ -386,7 +386,7 @@ void bdmcmcCopula( int *iter, int *burnin, int G[], double Ts[], double K[], int
 				// Finished (i,j) = 1------------------------------------------|
 
 				a11     = K[i * dim + i] - K121[0];	
-				sum_diag = - Dsij * K121[1] - Dsij * K121[2] + Dsjj * ( K022 - K121[3] );
+				sum_diag = Dsjj * ( K022 - K121[3] ) - Dsij * ( K121[1] + K121[2] );
 
 				// nu_star = b + sum( Gf[,i] * Gf[,j] )
 				nu_star = b1;
@@ -401,7 +401,6 @@ void bdmcmcCopula( int *iter, int *burnin, int G[], double Ts[], double K[], int
 				
 				char_g[counter] = G[ij] + '0'; 
 				counter++; 
-
 			}
 		}
 		
