@@ -21,12 +21,12 @@ void bdmcmcCopulap_links_multi_update( int *iter, int *burnin, int G[], double T
 			 double K_hat[], double p_links[],
 			 int *b, int *b_star, double D[], double Ds[], double *threshold, int *multi_update )
 {
-	int iteration = *iter, burn_in = *burnin;
+	int iteration = *iter, burn_in = *burnin, b1 = *b;
 	int multi_update_C = *multi_update;
 	
 	int selected_edge_i, selected_edge_j, selected_edge_ij, counter;
 
-	double Dsjj, Dsij, sum_diag, K022, a11, b1 = *b, sigmaj11, threshold_C = *threshold;
+	double Dsjj, Dsij, sum_diag, K022, a11, sigmaj11, threshold_C = *threshold;
 	int row, col, rowCol, i, j, k, ij, jj, nu_star, one = 1, two = 2, dim = *p, pxp = dim * dim, p1 = dim - 1, p1xp1 = p1 * p1, p2 = dim - 2, p2xp2 = p2 * p2, p2x2 = p2 * 2;
 
 	vector<double> sigma( pxp ); 
@@ -171,7 +171,7 @@ void bdmcmcCopulap_links_multi_update( int *iter, int *burnin, int G[], double T
 				// Finished (i,j) = 1------------------------------------------|
 
 				a11      = K[i * dim + i] - K121[0];	
-				sum_diag = - Dsij * K121[1] - Dsij * K121[2] + Dsjj * ( K022 - K121[3] );
+				sum_diag = - Dsij * ( K121[1] + K121[2] ) + Dsjj * ( K022 - K121[3] );
 
 				// nu_star = b + sum( Gf[,i] * Gf[,j] )
 				nu_star = b1;
@@ -247,7 +247,7 @@ void bdmcmcCopula_multi_update( int *iter, int *burnin, int G[], double Ts[], do
 			 int *b, int *b_star, double D[], double Ds[], double *threshold, int *multi_update )
 {
 	int multi_update_C = *multi_update;
-	int iteration = *iter, burn_in = *burnin;
+	int iteration = *iter, burn_in = *burnin, b1 = *b;
 	int counterallG = 0;
 	string string_g;
 	vector<string> sample_graphs_C( iteration - burn_in );
@@ -255,7 +255,7 @@ void bdmcmcCopula_multi_update( int *iter, int *burnin, int G[], double Ts[], do
 	int selected_edge_i, selected_edge_j, selected_edge_ij, counter, size_sample_graph = *size_sample_g;
 	bool this_one;
 
-	double Dsjj, Dsij, sum_diag, K022, a11, b1 = *b, sigmaj11, threshold_C = *threshold;
+	double Dsjj, Dsij, sum_diag, K022, a11, sigmaj11, threshold_C = *threshold;
 	int row, col, rowCol, i, j, k, ij, jj, nu_star, one = 1, two = 2, dim = *p, pxp = dim * dim, p1 = dim - 1, p1xp1 = p1 * p1, p2 = dim - 2, p2xp2 = p2 * p2, p2x2 = p2 * 2;
 
 	vector<double> sigma( pxp ); 
@@ -398,7 +398,7 @@ void bdmcmcCopula_multi_update( int *iter, int *burnin, int G[], double Ts[], do
 				// Finished (i,j) = 1------------------------------------------|
 
 				a11      = K[i * dim + i] - K121[0];	
-				sum_diag = - Dsij * K121[1] - Dsij * K121[2] + Dsjj * ( K022 - K121[3] );
+				sum_diag = - Dsij * ( K121[1] + K121[2] ) + Dsjj * ( K022 - K121[3] );
 
 				// nu_star = b + sum( Gf[,i] * Gf[,j] )
 				nu_star = b1;
