@@ -20,13 +20,13 @@ void bdmcmcExactp_links( int *iter, int *burnin, int G[], double Ts[], double K[
 			 double K_hat[], double p_links[],
 			 int *b, int *b_star, double Ds[], double *threshold )
 {
-	int iteration = *iter, burn_in = *burnin;
+	int iteration = *iter, burn_in = *burnin, b1 = *b;
 
 	int index_selected_edge, selected_edge_i, selected_edge_j, selected_edge_ij;
-	int row, col, rowCol, i, j, k, ij, jj, Dsjj, Dsij, counter, nu_star, one = 1, two = 2;
+	int row, col, rowCol, i, j, k, ij, jj, counter, nu_star, one = 1, two = 2;
 	int dim = *p, pxp = dim * dim, p1 = dim - 1, p1xp1 = p1 * p1, p2 = dim - 2, p2xp2 = p2 * p2, p2x2 = p2 * 2;
 
-	double sum_weights = 0.0, sum_diag, K022, a11, b1 = *b, sigmaj11, threshold_C = *threshold;
+	double Dsjj, Dsij, sum_weights = 0.0, sum_diag, K022, a11, sigmaj11, threshold_C = *threshold;
 	long double rate, sum_rates;
 	
 	vector<double> p_links_Cpp( pxp, 0.0 ); 
@@ -100,7 +100,7 @@ void bdmcmcExactp_links( int *iter, int *burnin, int G[], double Ts[], double K[
 		counter = 0;
 		// STEP 1: calculating birth and death rates --------------------------|		
 		for( j = 1; j < dim; j++ )
-		{
+		{		
 			jj   = j * dim + j;
 			Dsjj = Ds[jj];
 			
@@ -113,13 +113,13 @@ void bdmcmcExactp_links( int *iter, int *burnin, int G[], double Ts[], double K[
 				{
 					rowCol = col * p1 + row;
 					Kj22_inv[rowCol] = sigmaj22[rowCol] - sigmaj12[row] * sigmaj12[col] / sigmaj11;
-				}
-			
+				}		
+
 			for( i = 0; i < j; i++ )
 			{
 				ij   = j * dim + i;
 				Dsij = Ds[ij];
-
+				
 				// For (i,j) = 0 ----------------------------------------------|	
 				sub_row_mins( K, &Kj12[0], &j, &dim );   // K12 = K[j, -j]  
 				Kj12[ i ] = 0.0;                         // K12[1,i] = 0
@@ -156,7 +156,7 @@ void bdmcmcExactp_links( int *iter, int *burnin, int G[], double Ts[], double K[
 				// Finished (i,j) = 1------------------------------------------|
 
 				a11      = K[i * dim + i] - K121[0];	
-				sum_diag = - Dsij * K121[1] - Dsij * K121[2] + Dsjj * ( K022 - K121[3] );
+				sum_diag = Dsjj * ( K022 - K121[3] ) - Dsij * ( K121[1] + K121[2] );
 
 				// nu_star = b + sum( Gf[,i] * Gf[,j] )
 				nu_star = b1;
@@ -226,7 +226,7 @@ void bdmcmcExact( int *iter, int *burnin, int G[], double Ts[], double K[], int
 			 char *sample_graphs[], double graph_weights[], int *size_sample_g,
 			 int *b, int *b_star, double Ds[], double *threshold )
 {
-	int iteration = *iter, burn_in = *burnin;
+	int iteration = *iter, burn_in = *burnin, b1 = *b;
 	int counterallG = 0;
 	string string_g;
 	vector<string> sample_graphs_C( iteration - burn_in );
@@ -234,10 +234,10 @@ void bdmcmcExact( int *iter, int *burnin, int G[], double Ts[], double K[], int
 	bool this_one;
 
 	int index_selected_edge, selected_edge_i, selected_edge_j, selected_edge_ij, size_sample_graph = *size_sample_g;
-	int row, col, rowCol, i, j, k, ij, jj, Dsjj, Dsij, counter, nu_star, one = 1, two = 2;
+	int row, col, rowCol, i, j, k, ij, jj, counter, nu_star, one = 1, two = 2;
 	int dim = *p, pxp = dim * dim, p1 = dim - 1, p1xp1 = p1 * p1, p2 = dim - 2, p2xp2 = p2 * p2, p2x2 = p2 * 2;
 
-	double sum_weights = 0.0, sum_diag, K022, a11, b1 = *b, sigmaj11, threshold_C = *threshold;
+	double Dsjj, Dsij, sum_weights = 0.0, sum_diag, K022, a11, sigmaj11, threshold_C = *threshold;
 	long double rate, sum_rates;
 	
 	vector<double> sigma( pxp ); 
@@ -364,8 +364,8 @@ void bdmcmcExact( int *iter, int *burnin, int G[], double Ts[], double K[], int
 				F77_NAME(dgemm)( &transN, &transT, &two, &two, &p2, &alpha, &K12xK22_inv[0], &two, &K12[0], &two, &beta, &K121[0], &two );		
 				// Finished (i,j) = 1------------------------------------------|
 
-				a11     = K[i * dim + i] - K121[0];	
-				sum_diag = - Dsij * K121[1] - Dsij * K121[2] + Dsjj * ( K022 - K121[3] );
+				a11      = K[i * dim + i] - K121[0];	
+				sum_diag = Dsjj * ( K022 - K121[3] ) - Dsij * ( K121[1] + K121[2] );
 
 				// nu_star = b + sum( Gf[,i] * Gf[,j] )
 				nu_star = b1;
