@@ -20,14 +20,14 @@ void bdmcmcExactp_links_multi_update( int *iter, int *burnin, int G[], double Ts
 			 double K_hat[], double p_links[],
 			 int *b, int *b_star, double Ds[], double *threshold, int *multi_update )
 {
-	int iteration = *iter, burn_in = *burnin;
+	int iteration = *iter, burn_in = *burnin, b1 = *b;
 	int multi_update_C = *multi_update;
 
 	int selected_edge_i, selected_edge_j, selected_edge_ij;
-	int row, col, rowCol, i, j, k, ij, jj, Dsjj, Dsij, counter, nu_star, one = 1, two = 2;
+	int row, col, rowCol, i, j, k, ij, jj, counter, nu_star, one = 1, two = 2;
 	int dim = *p, pxp = dim * dim, p1 = dim - 1, p1xp1 = p1 * p1, p2 = dim - 2, p2xp2 = p2 * p2, p2x2 = p2 * 2;
 
-	double sum_weights = 0.0, sum_diag, K022, a11, b1 = *b, sigmaj11, threshold_C = *threshold;
+	double Dsjj, Dsij, sum_weights = 0.0, sum_diag, K022, a11, sigmaj11, threshold_C = *threshold;
 	long double rate, sum_rates;
 
 	vector<double> p_links_Cpp( pxp, 0.0 ); 
@@ -160,7 +160,7 @@ void bdmcmcExactp_links_multi_update( int *iter, int *burnin, int G[], double Ts
 				// Finished (i,j) = 1------------------------------------------|
 
 				a11      = K[i * dim + i] - K121[0];	
-				sum_diag = - Dsij * K121[1] - Dsij * K121[2] + Dsjj * ( K022 - K121[3] );
+				sum_diag = Dsjj * ( K022 - K121[3] ) - Dsij * ( K121[1] + K121[2] );
 
 				// nu_star = b + sum( Gf[,i] * Gf[,j] )
 				nu_star = b1;
@@ -234,7 +234,7 @@ void bdmcmcExact_multi_update( int *iter, int *burnin, int G[], double Ts[], dou
 			 int *b, int *b_star, double Ds[], double *threshold, int *multi_update )
 {
 	int multi_update_C = *multi_update;
-	int iteration = *iter, burn_in = *burnin;
+	int iteration = *iter, burn_in = *burnin, b1 = *b;
 	int counterallG = 0;
 	string string_g;
 	vector<string> sample_graphs_C( iteration - burn_in );
@@ -242,10 +242,10 @@ void bdmcmcExact_multi_update( int *iter, int *burnin, int G[], double Ts[], dou
 	bool this_one;
 
 	int selected_edge_i, selected_edge_j, selected_edge_ij, size_sample_graph = *size_sample_g;
-	int row, col, rowCol, i, j, k, ij, jj, Dsjj, Dsij, counter, nu_star, one = 1, two = 2;
+	int row, col, rowCol, i, j, k, ij, jj, counter, nu_star, one = 1, two = 2;
 	int dim = *p, pxp = dim * dim, p1 = dim - 1, p1xp1 = p1 * p1, p2 = dim - 2, p2xp2 = p2 * p2, p2x2 = p2 * 2;
 
-	double sum_weights = 0.0, sum_diag, K022, a11, b1 = *b, sigmaj11, threshold_C = *threshold;
+	double Dsjj, Dsij, sum_weights = 0.0, sum_diag, K022, a11, sigmaj11, threshold_C = *threshold;
 	long double rate, sum_rates;
 
 	vector<double> sigma( pxp ); 
@@ -376,7 +376,8 @@ void bdmcmcExact_multi_update( int *iter, int *burnin, int G[], double Ts[], dou
 				// Finished (i,j) = 1------------------------------------------|
 
 				a11      = K[i * dim + i] - K121[0];	
-				sum_diag = - Dsij * K121[1] - Dsij * K121[2] + Dsjj * ( K022 - K121[3] );
+				sum_diag = Dsjj * ( K022 - K121[3] ) - Dsij * ( K121[1] + K121[2] );
+
 
 				// nu_star = b + sum( Gf[,i] * Gf[,j] )
 				nu_star = b1;
